==> haskell-dataenc-0.14.0.7-14-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-dataenc.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: dataenc
version: 0.14.0.7
id: dataenc-0.14.0.7-HFeeAWdSa4cC3kwlgXNA4G
key: dataenc-0.14.0.7-HFeeAWdSa4cC3kwlgXNA4G
license: BSD-3-Clause
copyright: Magnus Therning, 2007-2012, Gracjan Polak, 2014
maintainer: Gracjan Polak <gracjanpolak@gmail.com>
author: Magnus Therning
homepage: http://www.haskell.org/haskellwiki/Library/Data_encoding
synopsis: Data encoding library
description:
    Data encoding library currently providing Base16, Base32,
    Base32Hex, Base64, Base64Url, Base85, Python string escaping,
    Quoted-Printable, URL encoding, uuencode, xxencode, and yEncoding.
category: Codec
abi: ab262752fdb596c7db147ee42c859168
exposed: True
exposed-modules:
    Codec.Binary.Base16 Codec.Binary.Base32 Codec.Binary.Base32Hex
    Codec.Binary.Base64 Codec.Binary.Base64Url Codec.Binary.Base85
    Codec.Binary.DataEncoding Codec.Binary.PythonString
    Codec.Binary.QuotedPrintable Codec.Binary.Url Codec.Binary.Uu
    Codec.Binary.Xx Codec.Binary.Yenc
hidden-modules: Codec.Binary.Util
import-dirs: /usr/lib/ghc-8.4.3/site-local/dataenc-0.14.0.7
library-dirs: /usr/lib/ghc-8.4.3/site-local/dataenc-0.14.0.7
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/dataenc-0.14.0.7
hs-libraries: HSdataenc-0.14.0.7-HFeeAWdSa4cC3kwlgXNA4G
depends:
    array-0.5.2.0 base-4.11.1.0 containers-0.5.11.0
abi-depends: array-0.5.2.0=dc85b03ee806d784249cc791da6109c3
             base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             containers-0.5.11.0=94bb4831ae701bd40855b2dc2d65cf7c
haddock-interfaces: /usr/share/doc/haskell-dataenc/html/dataenc.haddock
haddock-html: /usr/share/doc/haskell-dataenc/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-dataenc-0.14.0.7-15-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-dataenc.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: dataenc
version: 0.14.0.7
id: dataenc-0.14.0.7-3jwrEUJAotyJIhF0a60UP4
key: dataenc-0.14.0.7-3jwrEUJAotyJIhF0a60UP4
license: BSD-3-Clause
copyright: Magnus Therning, 2007-2012, Gracjan Polak, 2014
maintainer: Gracjan Polak <gracjanpolak@gmail.com>
author: Magnus Therning
homepage: http://www.haskell.org/haskellwiki/Library/Data_encoding
synopsis: Data encoding library
description:
    Data encoding library currently providing Base16, Base32,
    Base32Hex, Base64, Base64Url, Base85, Python string escaping,
    Quoted-Printable, URL encoding, uuencode, xxencode, and yEncoding.
category: Codec
abi: 1e718392cc25ef0043ec0d5ef6ac3b9d
exposed: True
exposed-modules:
    Codec.Binary.Base16 Codec.Binary.Base32 Codec.Binary.Base32Hex
    Codec.Binary.Base64 Codec.Binary.Base64Url Codec.Binary.Base85
    Codec.Binary.DataEncoding Codec.Binary.PythonString
    Codec.Binary.QuotedPrintable Codec.Binary.Url Codec.Binary.Uu
    Codec.Binary.Xx Codec.Binary.Yenc
hidden-modules: Codec.Binary.Util
import-dirs: /usr/lib/ghc-8.6.1/site-local/dataenc-0.14.0.7
library-dirs: /usr/lib/ghc-8.6.1/site-local/dataenc-0.14.0.7
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.6.1/dataenc-0.14.0.7
hs-libraries: HSdataenc-0.14.0.7-3jwrEUJAotyJIhF0a60UP4
depends:
    array-0.5.2.0 base-4.12.0.0 containers-0.6.0.1
haddock-interfaces: /usr/share/doc/haskell-dataenc/html/dataenc.haddock
haddock-html: /usr/share/doc/haskell-dataenc/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
